==> nextcloud-12.0.3-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Yorumlar",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "New comment …" : "Yorum ekle ...",
    "Delete comment" : "Yorumu sil",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "Edit comment" : "Yorumu düzenle",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir sohbet başlatın!",
    "More comments …" : "Diğer yorumlar ...",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with id {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "Comment" : "Yorum",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>Yorumlar</strong>",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Bir (artık) silinmiş kullanıcı “%s” hakkındaki bir yorumda sizden bahsetti",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Bir (artık) silinmiş kullanıcı “{file}” hakkındaki bir yorumda sizden bahsetti",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s, “%2$s” hakkındaki bir yorumda sizden bahsetti",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizden bahsetti"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-12.0.4-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Yorumlar",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "New comment …" : "Yorum ekle ...",
    "Delete comment" : "Yorumu sil",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "Edit comment" : "Yorumu düzenle",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir sohbet başlatın!",
    "More comments …" : "Diğer yorumlar ...",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with id {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "Comment" : "Yorum",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s, “%2$s” hakkındaki bir yorumda sizden bahsetti",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizden bahsetti",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Bir (artık) silinmiş kullanıcı “%s” hakkındaki bir yorumda sizden bahsetti",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Bir (artık) silinmiş kullanıcı “{file}” hakkındaki bir yorumda sizden bahsetti"
},
"nplurals=2; plural=(n > 1);");
